CntDirection

Enum CntDirection 

pub enum CntDirection {
    CW,
    CCW,
}
Enum to specify the direction in which a counter counts

This enum is used to turn the positive direction of counting around. By default, it is set to CW for positive counting, but can be set to CCW for positive counting.

Variants



CW

Clockwise counting direction



CCW

Counterclockwise counting direction