UndervoltageStatus

Enum UndervoltageStatus 

pub enum UndervoltageStatus {
    Ok,
    Undervoltage,
}
Power Status

If VDD falls below the power off supply level, the device is reset and the RAM initialized to the default value. This status bit indicates that this initialization has taken place (and you might want to consider re-initializing the device).

Variants



Ok

The device is running normally and has not been reset due to undervoltage.



Undervoltage

The device has been reset due to undervoltage.