Status0

Struct Status0 

pub struct Status0 { /* private fields */ }

Implementations

Source

impl Status0

pub fn tp_val(&self) -> bool

bit 0 - Read the tp_val field.

Touch probe registers TP1/TP2 loaded or new values loaded.

pub fn ovf_ref(&self) -> bool

bit 1 - Read the ovf_ref field.

Overflow of the reference counter. There were too many edges detected between two index pulses. The value of the UPD and REF registers is not valid.

pub fn upd_val(&self) -> bool

bit 2 - Read the upd_val field.

UPD value: Every time that the UPD register is loaded, the status bit UpDval is set to 1 until the status bit UPD or the register UPD is read out.

pub fn r_val(&self) -> bool

bit 3 - Read the r_val field.

Status bit that indicates that the reference value was loaded in the REF register after the “Zero codification” process. After power-on, this bit remains at 0 until the second different index pulse.

pub fn p_dwn(&self) -> bool

bit 4 - Read the p_dwn field.

Power down: If VDD reaches the power off supply level, the iC-MD is reset and the RAM initialized to the default value. This status bit indicates that this initialization has taken place.

pub fn zero_0(&self) -> bool

bit 5 - Read the zero_0 field.

Zero of counter 0 reached: The counter has reached the zero value.

pub fn ovf_0(&self) -> bool

bit 6 - Read the ovf_0 field.

Overflow of counter 0.

pub fn ab_err_0(&self) -> bool

bit 7 - Read the ab_err_0 field.

AB input decodification error for counter 0. It occurs if the counting frequency is too high or if two incrmeental edges are too close together.

pub fn set_tp_val(&mut self, value: bool)

bit 0 - Set the tp_val field.

Touch probe registers TP1/TP2 loaded or new values loaded.

pub fn set_ovf_ref(&mut self, value: bool)

bit 1 - Set the ovf_ref field.

Overflow of the reference counter. There were too many edges detected between two index pulses. The value of the UPD and REF registers is not valid.

pub fn set_upd_val(&mut self, value: bool)

bit 2 - Set the upd_val field.

UPD value: Every time that the UPD register is loaded, the status bit UpDval is set to 1 until the status bit UPD or the register UPD is read out.

pub fn set_r_val(&mut self, value: bool)

bit 3 - Set the r_val field.

Status bit that indicates that the reference value was loaded in the REF register after the “Zero codification” process. After power-on, this bit remains at 0 until the second different index pulse.

pub fn set_p_dwn(&mut self, value: bool)

bit 4 - Set the p_dwn field.

Power down: If VDD reaches the power off supply level, the iC-MD is reset and the RAM initialized to the default value. This status bit indicates that this initialization has taken place.

pub fn set_zero_0(&mut self, value: bool)

bit 5 - Set the zero_0 field.

Zero of counter 0 reached: The counter has reached the zero value.

pub fn set_ovf_0(&mut self, value: bool)

bit 6 - Set the ovf_0 field.

Overflow of counter 0.

pub fn set_ab_err_0(&mut self, value: bool)

bit 7 - Set the ab_err_0 field.

AB input decodification error for counter 0. It occurs if the counting frequency is too high or if two incrmeental edges are too close together.