pub struct Status2 { /* private fields */ }Implementations
Sourceimpl Status2
impl Status2
Sourcepub fn en_ssi(&self) -> bool
pub fn en_ssi(&self) -> bool
bit 0 - Read the en_ssi field.
EnSSI: Status of the SSI pin. If closed, the SSI interface is not enabled and the status bit is 0. Otherwise, if SSI is enabled (SLI pin is open), the status bit returns 1.
Sourcepub fn com_col(&self) -> bool
pub fn com_col(&self) -> bool
bit 1 - Read the com_col field.
Communication collision took place.
Sourcepub fn ext_warn(&self) -> bool
pub fn ext_warn(&self) -> bool
bit 2 - Read the ext_warn field.
ExtWarn: Status bit that indicates if the NWARN pin was either pulled-down from
outside or set to 0 from inside (an internal masked error has occured).
Sourcepub fn ext_err(&self) -> bool
pub fn ext_err(&self) -> bool
bit 3 - Read the ext_err field.
ExtErr: Status bit that indicates if the NERR pin was either pulled-down from
outside or set to 0 from inside (an internal masked error has occured).
Sourcepub fn p_dwn(&self) -> bool
pub fn p_dwn(&self) -> bool
bit 4 - Read the p_dwn field.
Power down: If VDD reaches the power off supply level, the iC-MD is reset and the RAM initialized to the default value. This status bit indicates that this initialization has taken place.
Sourcepub fn zero_2(&self) -> bool
pub fn zero_2(&self) -> bool
bit 5 - Read the zero_2 field.
Zero of counter 1 reached: The counter has reached the zero value.
Sourcepub fn ab_err_2(&self) -> bool
pub fn ab_err_2(&self) -> bool
bit 7 - Read the ab_err_2 field.
AB input decodification error for counter 1. It occurs if the counting frequency is too high or if two incrmeental edges are too close together.
Sourcepub fn set_en_ssi(&mut self, value: bool)
pub fn set_en_ssi(&mut self, value: bool)
bit 0 - Set the en_ssi field.
EnSSI: Status of the SSI pin. If closed, the SSI interface is not enabled and the status bit is 0. Otherwise, if SSI is enabled (SLI pin is open), the status bit returns 1.
Sourcepub fn set_com_col(&mut self, value: bool)
pub fn set_com_col(&mut self, value: bool)
bit 1 - Set the com_col field.
Communication collision took place.
Sourcepub fn set_ext_warn(&mut self, value: bool)
pub fn set_ext_warn(&mut self, value: bool)
bit 2 - Set the ext_warn field.
ExtWarn: Status bit that indicates if the NWARN pin was either pulled-down from
outside or set to 0 from inside (an internal masked error has occured).
Sourcepub fn set_ext_err(&mut self, value: bool)
pub fn set_ext_err(&mut self, value: bool)
bit 3 - Set the ext_err field.
ExtErr: Status bit that indicates if the NERR pin was either pulled-down from
outside or set to 0 from inside (an internal masked error has occured).
Sourcepub fn set_p_dwn(&mut self, value: bool)
pub fn set_p_dwn(&mut self, value: bool)
bit 4 - Set the p_dwn field.
Power down: If VDD reaches the power off supply level, the iC-MD is reset and the RAM initialized to the default value. This status bit indicates that this initialization has taken place.
Sourcepub fn set_zero_2(&mut self, value: bool)
pub fn set_zero_2(&mut self, value: bool)
bit 5 - Set the zero_2 field.
Zero of counter 1 reached: The counter has reached the zero value.
Sourcepub fn set_ab_err_2(&mut self, value: bool)
pub fn set_ab_err_2(&mut self, value: bool)
bit 7 - Set the ab_err_2 field.
AB input decodification error for counter 1. It occurs if the counting frequency is too high or if two incrmeental edges are too close together.